@@ -2,7 +2,7 @@
   
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -28,16 +28,16 @@ DEFUN_DLD(nrb_srf_basisfun_der__, args, nargout,"\
   octave_value_list retval, newargs;
 
   const NDArray points = args(0).array_value();
-  const Octave_map nrb = args(1).map_value();
+  const octave_scalar_map nrb = args(1).scalar_map_value();
 
   if (!error_state) 
     {
-      const Cell knots = nrb.contents("knots")(0).cell_value();
-      const NDArray coefs = nrb.contents("coefs")(0).array_value();
-      octave_idx_type m   = (nrb.contents("number")(0).vector_value())(0) - 1; // m    = size (nrb.coefs, 2) -1;
-      octave_idx_type n   = (nrb.contents("number")(0).vector_value())(1) - 1; // n    = size (nrb.coefs, 3) -1;
-      octave_idx_type p = (nrb.contents("order")(0).vector_value())(0) - 1;    // p    = nrb.order(1) -1;
-      octave_idx_type q = (nrb.contents("order")(0).vector_value())(1) - 1;    // q    = nrb.order(2) -1;
+      const Cell knots = nrb.contents("knots").cell_value();
+      const NDArray coefs = nrb.contents("coefs").array_value();
+      octave_idx_type m   = static_cast<octave_idx_type> ((nrb.contents("number").vector_value())(0)) - 1; // m    = size (nrb.coefs, 2) -1;
+      octave_idx_type n   = static_cast<octave_idx_type> ((nrb.contents("number").vector_value())(1)) - 1; // n    = size (nrb.coefs, 3) -1;
+      octave_idx_type p   = static_cast<octave_idx_type> ((nrb.contents("order").vector_value())(0)) - 1;  // p    = nrb.order(1) -1;
+      octave_idx_type q   = static_cast<octave_idx_type> ((nrb.contents("order").vector_value())(1)) - 1;  // q    = nrb.order(2) -1;
 
       Array<idx_vector> idx(dim_vector (2, 1), idx_vector(':')); 
       idx(0) = 0;
@@ -46,7 +46,7 @@ DEFUN_DLD(nrb_srf_basisfun_der__, args, nargout,"\
       idx(0) = 1;
       const NDArray v(points.index (idx).squeeze ()); // v = points(2,:);      
       
-      octave_idx_type npt = u.length (); // npt = length(u);
+      octave_idx_type npt = u.numel (); // npt = length(u);
 
       RowVector M(p+1, 0.0), N (q+1, 0.0);
       Matrix Nout(npt, (p+1)*(q+1), 0.0);
@@ -76,7 +76,7 @@ DEFUN_DLD(nrb_srf_basisfun_der__, args, nargout,"\
       Matrix Ik = feval (std::string("numbasisfun"), newargs, 1)(0).matrix_value (); // Ik = numbasisfun (spu, u, p, U);
 
       RowVector spv(v);
-      for (octave_idx_type ii(0); ii < v.length(); ii++)
+      for (octave_idx_type ii(0); ii < v.numel (); ii++)
 	{
 	  spv(ii) = findspan(n, q, v(ii), V);
 	} // spv  =  findspan (n, q, v, V);
@@ -91,7 +91,7 @@ DEFUN_DLD(nrb_srf_basisfun_der__, args, nargout,"\
 	  NuIkuk.insert (M, ii, 0);
 	} // NuIkuk = basisfun (spu, u, p, U);
 
-      Matrix NvJkvk(v.length (), q+1, 0.0);
+      Matrix NvJkvk(v.numel (), q+1, 0.0);
       for (octave_idx_type ii(0); ii < npt; ii++)
 	{
 	  basisfun(int(spv(ii)), v(ii), q, V, N);
@@ -111,14 +111,21 @@ DEFUN_DLD(nrb_srf_basisfun_der__, args, nargout,"\
 	for (octave_idx_type ii(0); ii < p+1; ii++) 
 	  for (octave_idx_type jj(0); jj < q+1; jj++) 
 	    {
-	      Num(k, ii+jj*(p+1)) = NuIkuk(k, ii) * NvJkvk(k, jj) * w(Ik(k, ii), Jk(k, jj));
+	      Num(k, ii+jj*(p+1)) = NuIkuk(k, ii) * NvJkvk(k, jj) * 
+                w(static_cast<octave_idx_type> (Ik(k, ii)), 
+                  static_cast<octave_idx_type> (Jk(k, jj)));
 	      Denom(k) += Num(k, ii+jj*(p+1));
 
-	      Num_du(k, ii+jj*(p+1)) = NuIkukprime(k, 1, ii) * NvJkvk(k, jj) * w(Ik(k, ii), Jk(k, jj));
+	      Num_du(k, ii+jj*(p+1)) = NuIkukprime(k, 1, ii) * NvJkvk(k, jj) * 
+                w(static_cast<octave_idx_type> (Ik(k, ii)), 
+                  static_cast<octave_idx_type> (Jk(k, jj)));
 	      Denom_du(k) += Num_du(k, ii+jj*(p+1));
 
-	      Num_dv(k, ii+jj*(p+1)) = NuIkuk(k, ii) * NvJkvkprime(k, 1, jj) * w(Ik(k, ii), Jk(k, jj));
-	      Denom_dv(k) += Num_dv(k, ii+jj*(p+1));
+	      Num_dv(k, ii+jj*(p+1)) = NuIkuk(k, ii) * NvJkvkprime(k, 1, jj) * 
+                w(static_cast<octave_idx_type> (Ik(k, ii)), 
+                  static_cast<octave_idx_type> (Jk(k, jj)));
+
+	      Denom_dv(k) += Num_dv(k, ii + jj * (p+1));
 	    }
 
       for (octave_idx_type k(0); k < npt; k++) 
