@@ -3,7 +3,7 @@
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -69,57 +69,57 @@ void onebasisfun__ (double u, octave_idx_type p, RowVector U, double *N)
     }
  
   double ln = u - U(0);
-  double ld = U(U.length () - 2) - U(0);
+  double ld = U(U.numel () - 2) - U(0);
   if (ld != 0)
     {
       double tmp;
-      onebasisfun__ (u, p-1, U.extract (0, U.length () - 2), &tmp);
+      onebasisfun__ (u, p-1, U.extract (0, U.numel () - 2), &tmp);
       *N += ln * tmp / ld; 
     }
-  double dn = U(U.length () - 1) - u;
-  double dd = U(U.length () - 1) - U(1);
+  double dn = U(U.numel () - 1) - u;
+  double dd = U(U.numel () - 1) - U(1);
   if (dd != 0)
     {
       double tmp;
-      onebasisfun__ (u, p-1, U.extract (1, U.length () - 1), &tmp);
+      onebasisfun__ (u, p-1, U.extract (1, U.numel () - 1), &tmp);
       *N += dn * tmp / dd;
     }
   return;
 }
 
+void onebasisfun__ (double u, double p, RowVector U, double *N)
+{ onebasisfun__ (u, static_cast<octave_idx_type> (p), U, N); }
 
 void onebasisfunder__ (double u, octave_idx_type p, RowVector U, double *N, double *Nder)
 {
   double aux;
-  *N = 0.0; *Nder = 0.0;                                                                                                                                             
-  if ((u <= U.min ()) || ( u > U.max ()))                                             
+  *N = 0.0; *Nder = 0.0;
+  if ((u <= U.min ()) || ( u > U.max ()))       
     return;
-  
-  else if (p == 0)                                                                    
-    {                                                                                 
-      *N = 1.0;                                                                        
-      *Nder = 0.0;                                                                     
+  else if (p == 0)
+    {
+      *N = 1.0;
+      *Nder = 0.0;
       return;
-    }
-  
-  else {                                                                             
-    
-    double ln = u - U(0);                                                              
-    double ld = U(U.length () - 2) - U(0);       
-                                      
-    if (ld != 0)                                                                     
+    }  
+  else {    
+    double ln = u - U(0);
+    double ld = U(U.numel () - 2) - U(0);
+
+    if (ld != 0)
       {
-        onebasisfun__ (u, p-1, U.extract (0, U.length () - 2), &aux);
-        aux = aux / ld;      
-        *N += ln * aux;                                                               
-        *Nder += p * aux;                                                             
-      }                                                                              
+        onebasisfun__ (u, p-1, U.extract (0, U.numel () - 2), &aux);
+        aux = aux / ld;
+        *N += ln * aux;
+        *Nder += p * aux;
+      }
     
-    double dn = U(U.length () - 1) - u;                                                
-    double dd = U(U.length () - 1) - U(1);                                             
-    if (dd != 0)                                                                                                           
+    double dn = U(U.numel () - 1) - u;
+    double dd = U(U.numel () - 1) - U(1);
+
+    if (dd != 0)
       { 
-        onebasisfun__ (u, p-1, U.extract (1, U.length () - 1), &aux);
+        onebasisfun__ (u, p-1, U.extract (1, U.numel () - 1), &aux);
         aux = aux / dd;
         *N    += dn *aux;
         *Nder -= p * aux;
@@ -181,7 +181,7 @@ TBASISFUN: Compute a B- or T-Spline basis function, and its derivatives, from it
   else 
     {
       RowVector p = args(1).row_vector_value ();
-      if (p.length() == 2) 
+      if (p.numel () == 2) 
         {
           Cell C = args(2).cell_value ();
           RowVector U = C(0).row_vector_value (true, true);
@@ -215,7 +215,7 @@ TBASISFUN: Compute a B- or T-Spline basis function, and its derivatives, from it
             }
         
         } 
-      else if (p.length() == 3) 
+      else if (p.numel () == 3) 
         {
           Cell C = args(2).cell_value ();
           RowVector U = C(0).row_vector_value (true, true);
